@@ -98,14 +98,24 @@ class _Query:
         return f'|> pivot(rowKey: {rows}, columnKey: {columns}, valueColumn: "{value}")'
 
     @add_to_query
-    def group(self, columns: (str, list, tuple), mode: str = 'by'):
+    def group(self, columns: (str, list, tuple) = None, mode: str = None):
         """
         Implements the GROUP function from FluxQL
         """
-        if isinstance(columns, str):
-            columns = [columns]
-        columns = json.dumps(columns)
-        return f'|> group(columns: {columns}, mode: "{mode}")'
+        if columns is not None:
+            if isinstance(columns, str):
+                columns = [columns]
+            columns = json.dumps(columns)
+            column_component = f'columns: {columns}'
+        else:
+            column_component = ''
+
+        if mode is not None:
+            mode_component = f', mode: "{mode}"'
+        else:
+            mode_component = ''
+
+        return f'|> group({column_component}{mode_component})'
 
     @add_to_query
     def sort(self, columns: (str, list, tuple), desc: bool = False):
@@ -131,6 +141,46 @@ class _Query:
         """
         return '|> last()'
 
+    @add_to_query
+    def drop(self, columns: list):
+        """
+        Implements the DROP function from FluxQL
+        """
+        return f'|> drop(columns: {columns})'
+
+    @add_to_query
+    def mean(self, column: str = '_value'):
+        """
+        Implements the MEAN function from FluxQL
+        """
+        return f'|> mean(column: "{column}")'
+
+    @add_to_query
+    def std(self, column: str = '_value', mode: str = 'sample'):
+        """
+        Implements the MEAN function from FluxQL
+        """
+        return f'|> stddev(column: "{column}", mode: "{mode}")'
+
+    @add_to_query
+    def count(self, column: str = '_value'):
+        """
+        Implements the MEAN function from FluxQL
+        """
+        return f'|> count(column: "{column}")'
+
+    @add_to_query
+    def map(self, operations: dict, keep_original: bool = True):
+        """
+        Implements the MAP function from FluxQL
+        :param operations: Dictionary of operations. Each key is the name of the new column and the item is a operation
+                           of ROW objects. Example: {column: ROW('first') + ROW('second')}
+        :param keep_original: True if the original columns need to be kept, False otherwise
+        """
+        starter = ' r with ' if keep_original else ''
+        components = ', '.join([f'{key}: {operations[key]}' for key in operations])
+        return '|> map(fn: (r) => ({ %s %s }))' % (starter, components)
+
     #######################################
     # Execution methods
     #######################################
